complete -c rage -l max-work-factor -r
complete -c rage -s r -l recipient -r
complete -c rage -s R -l recipients-file -r
complete -c rage -s i -l identity -r
complete -c rage -s o -l output -r
complete -c rage -s h -l help -d 'Print help information'
complete -c rage -s e -l encrypt
complete -c rage -s d -l decrypt
complete -c rage -s p -l passphrase
complete -c rage -s a -l armor
